#include "catch2/catch_test_macros.hpp"

#include "slic3r/Utils/Secrets.hpp"

/*TEST_CASE("Secret store test", "[secretstore]") {

    REQUIRE(Slic3r::check_secrets());
}*/
